//
//  AdController.h
//  BSAAdFramework
//
//  Created by Rick Fillion on 10/07/09.
//  Copyright 2009 BuySellAds. All rights reserved.
//

#import <Cocoa/Cocoa.h>
#import "BSAZoneFormat.h"

@class BSAAd;

/**
 @brief Main controller class that interacts with BuySellAds servers.
 
 This is a singleton class, accessible via the +sharedController method.  The first
 step you'll want to do is use the -loadAdsWithKey: method to load your ads from the 
 servers.  In theory that's the only interaction you'll require to do with this class.
  
 */
@interface BSAAdController : NSObject {
    NSMutableDictionary *zones;
}

/// Returns the singleton instance
+ (BSAAdController *)sharedController;
/// Loads ads from the BuySellAds server associated with the specified key.
- (void)loadAdsWithKey:(NSString *)key;
/// Returns all ads for the specified zone identifier, or nil if the zone hasn't been loaded.
- (NSArray *)allAdsForZoneId:(NSNumber *)zoneIdentifier;
/// Returns a specified number of ads.  If the zone doesn't have a sufficient
/// number of ads to not repeat, then placeholder ads are used. Returns nil if the zone hasn't been loaded.
- (NSArray *)randomAdsForZoneId:(NSNumber *)zoneIdentifier howMany:(NSUInteger)howmany;
/// Returns the size (currently based on the image size) for ads in the specified zone identifier, or NSZeroSize if the zone hasn't been loaded.
- (NSSize)sizeForZoneId:(NSNumber *)zoneIdentifier;
/// Returns the number of ads that should appear in a zone with the specified zone identifier, or nil if the zone hasn't been loaded.
- (NSNumber *)numberOfAdsForZoneId:(NSNumber *)zoneIdentifier;
/// Returns the BSAZoneFormat of the zone with specified zone identifier, or NSNotFound if the zone hasn't been loaded.
- (BSAZoneFormat)zoneFormatForZoneId:(NSNumber *)zoneIdentifier;
/// Returns the site identifier for the zone with specified zone identifier, or nil if the zone hasn't been loaded.
- (NSNumber *)siteIdForZoneId:(NSNumber *)zoneIdentifier;
/// Returns the URL used to buy an ad in the zone with specified identifier, or nil if the zone hasn't been loaded.
- (NSString *)buyUrlForZoneId:(NSNumber *)zoneIdentifier;
/// Returns whether to show a placeholder ad in a zone with specified identifier.
- (BOOL)showsPlaceholderAdForZoneId:(NSNumber *)zoneIdentifier;
/// Returns whether to repeate the placeholder ad in a zone with specified identifier.
- (BOOL)repeatsPlaceholderAdsForZoneId:(NSNumber *)zoneIdentifier;

@end
